@@ -32,7 +32,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <KDirModel>
 #include <KFileItem>
 #include <KFilePlacesModel>
-#include <KFormat>
 
 // Local
 #include "gwenview_lib_debug.h"
@@ -61,7 +60,7 @@ struct RecentFilesItem : public QStandardItem {
 
         setData(mUrl, KFilePlacesModel::UrlRole);
 
-        KFileItem fileItem(mUrl);
+        const KFileItem fileItem(mUrl);
         setData(QVariant(fileItem), KDirModel::FileItemRole);
     }
 
@@ -70,7 +69,7 @@ private:
 };
 
 struct RecentFilesModelPrivate {
-    RecentFilesModel *q;
+    RecentFilesModel *q = nullptr;
 
     QMap<QUrl, RecentFilesItem *> mRecentFilesItemForUrl;
 };
@@ -104,7 +103,7 @@ bool RecentFilesModel::removeRows(int start, int count, const QModelIndex &paren
 {
     Q_ASSERT(!parent.isValid());
     for (int row = start + count - 1; row >= start; --row) {
-        auto *historyItem = static_cast<RecentFilesItem *>(item(row, 0));
+        auto historyItem = static_cast<RecentFilesItem *>(item(row, 0));
         Q_ASSERT(historyItem);
         d->mRecentFilesItemForUrl.remove(historyItem->url());
     }
