@@ -26,8 +26,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 // Qt
 #include <QAction>
+#include <QActionGroup>
 #include <QHBoxLayout>
 #include <QSlider>
+#include <QToolButton>
 // KF
 
 // Local
@@ -51,10 +53,11 @@ inline qreal zoomForSliderValue(int sliderValue)
 }
 
 struct ZoomWidgetPrivate {
-    ZoomWidget *q;
+    ZoomWidget *q = nullptr;
 
-    ZoomSlider *mZoomSlider;
-    ZoomComboBox *mZoomComboBox;
+    QToolButton *mFitButton = nullptr;
+    ZoomSlider *mZoomSlider = nullptr;
+    ZoomComboBox *mZoomComboBox = nullptr;
     QAction *mActualSizeAction = nullptr;
 
     bool mZoomUpdatedBySlider;
@@ -78,21 +81,24 @@ ZoomWidget::ZoomWidget(QWidget *parent)
     d->q = this;
     d->mZoomUpdatedBySlider = false;
 
-    setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Minimum);
+    setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Preferred);
 
-    d->mZoomSlider = new ZoomSlider;
+    d->mFitButton = new QToolButton(this);
+
+    d->mZoomSlider = new ZoomSlider(this);
     d->mZoomSlider->setMinimumWidth(150);
     d->mZoomSlider->slider()->setSingleStep(int(PRECISION));
     d->mZoomSlider->slider()->setPageStep(3 * int(PRECISION));
     connect(d->mZoomSlider->slider(), &QAbstractSlider::actionTriggered, this, &ZoomWidget::slotZoomSliderActionTriggered);
 
-    d->mZoomComboBox = new ZoomComboBox;
+    d->mZoomComboBox = new ZoomComboBox(this);
     connect(d->mZoomComboBox, &ZoomComboBox::zoomChanged, this, &ZoomWidget::zoomChanged);
 
     // Layout
-    auto *layout = new QHBoxLayout(this);
+    auto layout = new QHBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
     layout->setSpacing(0);
+    layout->addWidget(d->mFitButton);
     layout->addWidget(d->mZoomSlider);
     layout->addWidget(d->mZoomComboBox);
 }
@@ -104,12 +110,15 @@ ZoomWidget::~ZoomWidget()
 
 void ZoomWidget::setActions(QAction *zoomToFitAction, QAction *actualSizeAction, QAction *zoomInAction, QAction *zoomOutAction, QAction *zoomToFillAction)
 {
+    d->mFitButton->setDefaultAction(zoomToFitAction);
+    d->mFitButton->setToolButtonStyle(Qt::ToolButtonStyle::ToolButtonTextOnly);
+
     d->mZoomSlider->setZoomInAction(zoomInAction);
     d->mZoomSlider->setZoomOutAction(zoomOutAction);
 
     d->mZoomComboBox->setActions(zoomToFitAction, zoomToFillAction, actualSizeAction);
 
-    auto *actionGroup = new QActionGroup(d->q);
+    auto actionGroup = new QActionGroup(d->q);
     actionGroup->addAction(zoomToFitAction);
     actionGroup->addAction(zoomToFillAction);
     actionGroup->addAction(actualSizeAction);
